@@ -1,30 +1,10 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of this repository contains the full copyright notices and license terms.
+#This file is part of Tryton.  The COPYRIGHT file at the top level of
+#this repository contains the full copyright notices and license terms.
 """
 %prog [options]
 """
 import os
 import sys
-
-if os.name == 'nt':
-    sys.path.insert(0, os.path.join(os.getcwd(), os.path.dirname(sys.argv[0]),
-                                    'GTK\\bin'))
-    sys.path.insert(0, os.path.join(os.getcwd(), os.path.dirname(sys.argv[0]),
-                                    'GTK\\lib'))
-    os.environ['PATH'] = os.path.join(os.getcwd(), os.path.dirname(sys.argv[0]),
-                                      'GTK\\bin') + ';' + os.environ['PATH']
-    os.environ['PATH'] = os.path.join(os.getcwd(), os.path.dirname(sys.argv[0]),
-                                      'GTK\\lib') + ';' + os.environ['PATH']
-
-elif os.name == 'mac' or \
-        (hasattr(os, 'uname') and os.uname()[0] == 'Darwin'):
-    resources = os.path.join(os.path.dirname(sys.argv[0]), '..', 'Resources')
-    pixbuf_loader = os.path.join(resources, 'gdk-pixbuf.loaders')
-    if os.path.isfile(pixbuf_loader):
-        os.environ['GDK_PIXBUF_MODULE_FILE'] = pixbuf_loader
-    pangorc = os.path.join(resources, 'pangorc')
-    if os.path.isfile(pangorc):
-        os.environ['PANGO_RC_FILE'] = pangorc
-
 import pygtk
 pygtk.require('2.0')
 import gtk
@@ -62,9 +42,9 @@ class TrytonClient(object):
             if logger:
                 log = logging.getLogger(logger)
                 log.setLevel(loglevel[CONFIG['logging.level'].upper()])
-        if not CONFIG['logging.logger']:
+        if CONFIG['logging.default']:
             logging.getLogger().setLevel(
-                    loglevel[CONFIG['logging.level'].upper()])
+                    loglevel[CONFIG['logging.default'].upper()])
 
         if not hasattr(mx.DateTime, 'strptime'):
             mx.DateTime.strptime = lambda x, y: mx.DateTime.mktime(
