@@ -30,6 +30,7 @@ try:
     import ssl
 except ImportError:
     ssl = None
+import dis
 
 _ = gettext.gettext
 
@@ -319,6 +320,8 @@ def file_open(filename, type, parent, print_p=False):
         os.waitpid(pid, 0)
         return
     cmd = ''
+    if isinstance(CONFIG['client.actions'], basestring):
+        CONFIG['client.actions'] = safe_eval(CONFIG['client.actions'])
     if type in CONFIG['client.actions']:
         if print_p:
             cmd = CONFIG['client.actions'][type][1]
@@ -386,22 +389,36 @@ def mailto(to=None, cc=None, subject=None, body=None, attachment=None):
     #http://www.faqs.org/rfcs/rfc2368.html
     url = "mailto:"
     if to:
+        if isinstance(to, unicode):
+            to = to.encode('utf-8')
         url += urllib.quote(to.strip(), "@,")
     url += '?'
     if cc:
+        if isinstance(cc, unicode):
+            cc = cc.encode('utf-8')
         url += "&cc=" + urllib.quote(cc, "@,")
     if subject:
+        if isinstance(subject, unicode):
+            subject = subject.encode('utf-8')
         url += "&subject=" + urllib.quote(subject, "")
     if body:
+        if isinstance(body, unicode):
+            body = body.encode('utf-8')
         body = "\r\n".join(body.splitlines())
         url += "&body=" + urllib.quote(body, "")
     if attachment:
+        if isinstance(attachment, unicode):
+            attachment = attachment.encode('utf-8')
         url += "&attachment=" + urllib.quote(attachment, "")
     webbrowser.open(url, new=1)
 
 def error(title, parent, details):
     log = logging.getLogger('common.message')
     log.error('%s' % details)
+
+    if title == details:
+        title = ''
+
     dialog = gtk.Dialog(_('Error'), parent,
             gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT)
     dialog.set_icon(TRYTON_ICON)
@@ -572,7 +589,8 @@ def send_bugtracker(msg, parent):
                         'issue%s' % issue_id, parent)
             webbrowser.open(CONFIG['roundup.url'] + 'issue%s' % issue_id, new=2)
         except Exception, exception:
-            if 'roundup.cgi.exceptions.Unauthorised' in exception.faultString:
+            if hasattr(exception, 'faultString') \
+                    and 'roundup.cgi.exceptions.Unauthorised' in exception.faultString:
                 message(_('Connection error!\n' \
                         'Bad username or password!'), parent)
                 return send_bugtracker(msg, parent)
@@ -1030,3 +1048,162 @@ COLORS = {
 DT_FORMAT = '%Y-%m-%d'
 HM_FORMAT = '%H:%M:%S'
 DHM_FORMAT = DT_FORMAT + ' ' + HM_FORMAT
+
+FLOAT_TIME_CONV = {
+    'Y': 8760,
+    'M': 672,
+    'w': 168,
+    'd': 24,
+    'h': 1,
+    'm': 1.0/60,
+}
+
+FLOAT_TIME_SEPS = {
+    'Y': _('Y'),
+    'M': _('M'),
+    'w': _('w'),
+    'd': _('d'),
+    'h': _('h'),
+    'm': _('m'),
+}
+
+def text_to_float_time(text, conv=None):
+    try:
+        try:
+            return locale.atof(text)
+        except:
+            pass
+        if conv:
+            tmp_conv = FLOAT_TIME_CONV.copy()
+            tmp_conv.update(conv)
+            conv = tmp_conv
+        else:
+            conv = FLOAT_TIME_CONV
+        for key in FLOAT_TIME_SEPS.keys():
+            text = text.replace(FLOAT_TIME_SEPS[key], key + ' ')
+        value = 0
+        for buf in text.split(' '):
+            buf = buf.strip()
+            if ':' in buf:
+                hour, min = buf.split(':')
+                value += abs(int(hour or 0))
+                value += abs(int(min or 0) * conv['m'])
+                continue
+            elif '-' in buf and not buf.startswith('-'):
+                hour, min = buf.split('-')
+                value += abs(int(hour or 0))
+                value += abs(int(min or 0) * conv['m'])
+                continue
+            try:
+                value += abs(locale.atof(buf))
+                continue
+            except:
+                pass
+            for sep in conv.keys():
+                if buf.endswith(sep):
+                    value += abs(locale.atof(buf[:-len(sep)])) * conv[sep]
+                    break
+        if text.startswith('-'):
+            value *= -1
+        return value
+    except:
+        return 0.0
+
+def float_time_to_text(val, conv=None):
+    if conv:
+        tmp_conv = FLOAT_TIME_CONV.copy()
+        tmp_conv.update(conv)
+        conv = tmp_conv
+    else:
+        conv = FLOAT_TIME_CONV
+
+    value = ''
+    if val < 0:
+        value += '-'
+    val = abs(val)
+    years = int(val / conv['Y'])
+    val = val - years * conv['Y']
+    months = int(val / conv['M'])
+    val = val - months * conv['M']
+    weeks = int(val / conv['w'])
+    val = val - weeks * conv['w']
+    days = int(val / conv['d'])
+    val = val - days * conv['d']
+    hours = int(val)
+    val = val - hours
+    mins = int((val% 1 + 0.01) / conv['m'])
+    if years:
+        value += ' ' + locale.format('%d' + FLOAT_TIME_SEPS['Y'],
+                years, True)
+    if months:
+        value += ' ' + locale.format('%d' + FLOAT_TIME_SEPS['M'],
+                months, True)
+    if weeks:
+        value += ' ' + locale.format('%d' + FLOAT_TIME_SEPS['w'],
+                weeks, True)
+    if days:
+        value += ' ' + locale.format('%d' + FLOAT_TIME_SEPS['d'],
+                days, True)
+    if hours or mins:
+        value += ' %02d:%02d' % (hours, mins)
+    value = value.strip()
+    return value
+
+def filter_domain(domain):
+    '''
+    Return the biggest subset of domain with only AND operator
+    '''
+    res = []
+    for arg in domain:
+        if isinstance(arg, basestring):
+            if arg == 'OR':
+                res = []
+                break
+            continue
+        if isinstance(arg, tuple):
+            res.append(arg)
+        elif isinstance(arg, list):
+            res.extend(filter_domain(arg))
+    return res
+
+_ALLOWED_CODES = set(dis.opmap[x] for x in [
+    'POP_TOP','ROT_TWO','ROT_THREE','ROT_FOUR','DUP_TOP',
+    'BUILD_LIST','BUILD_MAP','BUILD_TUPLE',
+    'LOAD_CONST','RETURN_VALUE','STORE_SUBSCR',
+    'UNARY_POSITIVE','UNARY_NEGATIVE','UNARY_NOT',
+    'UNARY_INVERT','BINARY_POWER','BINARY_MULTIPLY',
+    'BINARY_DIVIDE','BINARY_FLOOR_DIVIDE','BINARY_TRUE_DIVIDE',
+    'BINARY_MODULO','BINARY_ADD','BINARY_SUBTRACT',
+    'BINARY_LSHIFT','BINARY_RSHIFT','BINARY_AND','BINARY_XOR', 'BINARY_OR',
+    'STORE_MAP', 'LOAD_NAME', 'CALL_FUNCTION', 'COMPARE_OP', 'LOAD_ATTR',
+    'STORE_NAME', 'GET_ITER', 'FOR_ITER', 'LIST_APPEND', 'JUMP_ABSOLUTE',
+    'DELETE_NAME', 'JUMP_IF_TRUE', 'JUMP_IF_FALSE', 'BINARY_SUBSCR',
+    ] if x in dis.opmap)
+
+
+def safe_eval(source, data=None):
+    if '__subclasses__' in source:
+        raise ValueError('__subclasses__ not allowed')
+    c = compile(source, '', 'eval')
+    codes = []
+    s = c.co_code
+    i = 0
+    while i < len(s):
+        code = ord(s[i])
+        codes.append(code)
+        if code >= dis.HAVE_ARGUMENT:
+            i += 3
+        else:
+            i += 1
+    for code in codes:
+        if code not in _ALLOWED_CODES:
+            raise ValueError('opcode %s not allowed' % dis.opname[code])
+    return eval(c, {'__builtins__': {
+        'True': True,
+        'False': False,
+        'str': str,
+        'globals': locals,
+        'locals': locals,
+        'bool': bool,
+        'dict': dict,
+        }}, data)
