@@ -1,4 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of this repository contains the full copyright notices and license terms.
+#This file is part of Tryton.  The COPYRIGHT file at the top level of
+#this repository contains the full copyright notices and license terms.
 "Options"
 import ConfigParser
 import optparse
@@ -8,6 +9,7 @@ from version import VERSION
 import logging
 import sys
 import locale
+import gtk
 
 _ = gettext.gettext
 
@@ -60,23 +62,26 @@ class ConfigManager(object):
     "Config manager"
 
     def __init__(self):
-        self.options = {
+        self.defaults = {
             'login.login': 'admin',
             'login.server': 'localhost',
             'login.port': '8070',
             'login.db': False,
-            'client.modepda': False,
-            'client.toolbar': 'default',
             'tip.autostart': False,
             'tip.position': 0,
             'logging.logger': '',
             'logging.level': 'ERROR',
-            'client.default_path': get_home_dir(),
+            'logging.default': 'ERROR',
             'form.toolbar': True,
+            'form.statusbar': True,
+            'client.default_width': 900,
+            'client.default_height': 750,
+            'client.modepda': False,
+            'client.toolbar': 'default',
             'client.form_tab': 'left',
-            'client.form_tab_orientation': 90,
-            'client.tree_width': True,
+            'client.save_width_height': True,
             'client.spellcheck': False,
+            'client.default_path': get_home_dir(),
             'client.lang': locale.getdefaultlocale()[0],
             'client.language_direction': 'ltr',
             'client.actions': {
@@ -86,24 +91,29 @@ class ConfigManager(object):
                     1: find_path(['ooffice', 'ooffice2'], '-p "%s"')},
                 'pdf': {0: find_path(['evince', 'xpdf', 'gpdf',
                     'kpdf', 'epdfview', 'acroread'], '"%s"'), 1: ''},
-                'png': {0: find_path(['display', 'qiv', 'eye'], '"%s"'), 1: ''},
+                'png': {0: find_path(['feh', 'display', 'qiv', 'eye'], '"%s"'), 1: ''},
                 'csv': {0: find_path(['ooffice', 'ooffice2'], '"%s"'),
                     1: find_path(['ooffice', 'ooffice2'], '-p "%s"')},
                 },
             'client.email': '',
+            'client.can_change_accelerators': False,
             'roundup.url': 'http://bugs.tryton.org/roundup/',
             'roundup.xmlrpc': 'roundup-xmlrpc.tryton.org',
         }
+        self.config = {}
+        self.options = {
+            'login.host': True
+        }
         parser = optparse.OptionParser(version=("Tryton %s" % VERSION))
         parser.add_option("-c", "--config", dest="config",
                 help=_("specify alternate config file"))
         parser.add_option("-v", "--verbose", action="store_true",
                 default=False, dest="verbose",
-                help=_("enable basic debugging"))
+                help=_("logging everything at INFO level"))
         parser.add_option("-d", "--log", dest="log_logger", default='',
                 help=_("specify channels to log"))
         parser.add_option("-l", "--log-level", dest="log_level",
-                default='ERROR', help=_("specify the log level: " \
+                help=_("specify the log level: " \
                         "INFO, DEBUG, WARNING, ERROR, CRITICAL"))
         parser.add_option("-u", "--user", dest="login",
                 help=_("specify the login user"))
@@ -114,14 +124,16 @@ class ConfigManager(object):
         opt = parser.parse_args()[0]
 
 
+        if opt.config and not os.path.isfile(opt.config):
+            raise Exception(_('File "%s" not found') % (opt.config,))
         self.rcfile = opt.config or os.path.join(get_home_dir(), '.tryton')
         self.load()
 
-        self.options['logging.logger'] = opt.log_logger
-        if opt.verbose and opt.log_level == 'ERROR':
-            self.options['logging.level'] = 'INFO'
-        else:
-            self.options['logging.level'] = opt.log_level
+        for arg in ('log_level', 'log_logger'):
+            if getattr(opt, arg):
+                self.options['logging.'+arg[4:]] = getattr(opt, arg)
+        if opt.verbose:
+            self.options['logging.default'] = 'INFO'
 
         for arg in ('login', 'port', 'server'):
             if getattr(opt, arg):
@@ -130,15 +142,13 @@ class ConfigManager(object):
     def save(self):
         try:
             configparser = ConfigParser.ConfigParser()
-            for option in self.options.keys():
-                if not len(option.split('.')) == 2:
-                    continue
-                section, name = option.split('.')
-                if section in ('logging'):
+            for entry in self.config.keys():
+                if not len(entry.split('.')) == 2:
                     continue
+                section, name = entry.split('.')
                 if not configparser.has_section(section):
                     configparser.add_section(section)
-                configparser.set(section, name, self.options[option])
+                configparser.set(section, name, self.config[entry])
             configparser.write(file(self.rcfile, 'wb'))
         except:
             logging.getLogger('common.options').warn(
@@ -148,33 +158,25 @@ class ConfigManager(object):
         return True
 
     def load(self):
-        try:
-            if not os.path.isfile(self.rcfile):
-                return False
-
-            configparser = ConfigParser.ConfigParser()
-            configparser.read([self.rcfile])
-            for section in configparser.sections():
-                for (name, value) in configparser.items(section):
-                    if value.lower() == 'true':
-                        value = True
-                    elif value.lower() == 'false':
-                        value = False
-                    if section == 'client' and name == 'actions':
-                        value = eval(value)
-                    self.options[section + '.' + name] = value
-        except:
-            logging.getLogger('options').warn(
-                    _('Unable to read config file %s!') % \
-                            (self.rcfile,))
-            return False
+        configparser = ConfigParser.ConfigParser()
+        configparser.read([self.rcfile])
+        for section in configparser.sections():
+            for (name, value) in configparser.items(section):
+                if value.lower() == 'true':
+                    value = True
+                elif value.lower() == 'false':
+                    value = False
+                self.config[section + '.' + name] = value
         return True
 
-    def __setitem__(self, key, value):
+    def __setitem__(self, key, value, config=True):
         self.options[key] = value
+        if config:
+            self.config[key] = value
 
     def __getitem__(self, key):
-        return self.options[key]
+        return self.options.get(key, self.config.get(key,
+            self.defaults.get(key)))
 
 CONFIG = ConfigManager()
 CURRENT_DIR = os.path.abspath(os.path.normpath(os.path.join(
@@ -189,18 +191,6 @@ if not os.path.isdir(PIXMAPS_DIR):
             os.path.dirname(sys.argv[0])))
         PIXMAPS_DIR = os.path.join(PREFIX, 'share', 'pixmaps', 'tryton')
 
-if os.name == 'nt':
-    sys.path.insert(0, os.path.join(CURRENT_DIR, 'GTK\\bin'))
-    sys.path.insert(0, os.path.join(CURRENT_DIR, 'GTK\\lib'))
-    sys.path.insert(0, os.path.join(CURRENT_DIR))
-    os.environ['PATH'] = os.path.join(CURRENT_DIR, 'GTK\\lib') + ";" + \
-            os.environ['PATH']
-    os.environ['PATH'] = os.path.join(CURRENT_DIR, 'GTK\\bin') + ";" + \
-            os.environ['PATH']
-    os.environ['PATH'] = os.path.join(CURRENT_DIR) + ";" + os.environ['PATH']
-
-import gtk
-
 TRYTON_ICON = gtk.gdk.pixbuf_new_from_file(
         os.path.join(PIXMAPS_DIR, '..', 'tryton-icon.png'))
 
