@@ -26,6 +26,7 @@ import base64
 import tryton.translate as translate
 import tryton.plugins
 import pango
+import time
 try:
     import igemacintegration
 except ImportError:
@@ -43,12 +44,15 @@ class Main(object):
         super(Main, self).__init__()
 
         self.window = gtk.Window()
-        self.window.set_default_size(900, 750)
+        self._width = int(CONFIG['client.default_width'])
+        self._height = int(CONFIG['client.default_height'])
+        self.window.set_default_size(self._width, self._height)
         self.window.set_resizable(True)
         self.window.set_title('Tryton')
         self.window.set_icon(TRYTON_ICON)
         self.window.connect("destroy", Main.sig_quit)
         self.window.connect("delete_event", self.sig_delete)
+        self.window.connect('configure_event', self.sig_configure)
 
         self.accel_group = gtk.AccelGroup()
         self.window.add_accel_group(self.accel_group)
@@ -105,10 +109,13 @@ class Main(object):
         self.vbox = gtk.VBox()
         self.window.add(self.vbox)
 
+        self.status_hbox = None
         self.menubar = None
         self.menuitem_user = None
         self.menuitem_form = None
         self.menuitem_plugins = None
+
+        self.set_statusbar()
         self.set_menubar()
 
         if igemacintegration:
@@ -131,9 +138,6 @@ class Main(object):
         self.notebook.connect_after('switch-page', self._sig_page_changt)
         self.vbox.pack_start(self.notebook, True, True)
 
-        self.status_hbox = None
-        self.set_statusbar()
-
         self.window.show_all()
 
         self.pages = []
@@ -148,11 +152,16 @@ class Main(object):
         self.sb_set()
 
         settings = gtk.settings_get_default()
-        settings.set_long_property('gtk-button-images', 1, 'Tryton:gui.main')
-        settings.set_property('gtk-can-change-accels', True)
+        settings.set_property('gtk-button-images', True)
+        settings.set_property('gtk-can-change-accels',
+                CONFIG['client.can_change_accelerators'])
+        try:
+            settings.set_property('gtk-keynav-cursor-only', True)
+        except TypeError:
+            pass
 
-        self.sig_toolbar()
-        self.sig_mode()
+        self.sig_toolbar_show()
+        self.sig_statusbar_show()
 
         if os.name in ('nt', 'mac') or \
                 (hasattr(os, 'uname') and os.uname()[0] == 'Darwin'):
@@ -254,53 +263,24 @@ class Main(object):
             self.vbox.pack_end(self.status_hbox, False, True, padding=2)
 
         if not update:
-            self.sb_servername = gtk.Statusbar()
-            self.sb_servername.set_size_request(150, -1)
-            self.sb_servername.set_has_resize_grip(False)
-            self.status_hbox.pack_start(self.sb_servername, True, True)
+            self.sb_username = gtk.Label()
+            self.sb_username.set_alignment(0.0, 0.5)
+            self.status_hbox.pack_start(self.sb_username, True, True, padding=5)
 
-        if not update:
-            self.sb_username = gtk.Statusbar()
-            self.sb_username.set_size_request(130, -1)
-            self.sb_username.set_has_resize_grip(False)
-            self.status_hbox.pack_start(self.sb_username, True, True)
+            self.sb_requests = gtk.Label()
+            self.sb_requests.set_alignment(0.5, 0.5)
+            self.status_hbox.pack_start(self.sb_requests, True, True,
+                    padding=5)
 
-        if not update:
-            self.sb_requests = gtk.Statusbar()
-            self.sb_requests.set_size_request(130, -1)
-            self.sb_requests.set_has_resize_grip(False)
-            self.status_hbox.pack_start(self.sb_requests, True, True)
+            self.sb_servername = gtk.Label()
+            self.sb_servername.set_alignment(1.0, 0.5)
+            self.status_hbox.pack_start(self.sb_servername, True, True,
+                    padding=5)
 
-        if not update:
-            button_request_new = gtk.Button()
-            self.button_request_new = button_request_new
-            image = gtk.Image()
-            image.set_from_stock('tryton-mail-message-new', gtk.ICON_SIZE_MENU)
-            button_request_new.set_image(image)
-            button_request_new.set_relief(gtk.RELIEF_NONE)
-            button_request_new.connect('clicked', self.sig_request_new)
-            button_request_new.set_sensitive(False)
-            self.status_hbox.pack_start(button_request_new, False, True)
-        self.tooltips.set_tip(self.button_request_new, _('Send a new request'))
-
-        if not update:
-            button_request_search = gtk.Button()
-            self.button_request_search = button_request_search
-            image = gtk.Image()
-            image.set_from_stock('tryton-find', gtk.ICON_SIZE_MENU)
-            button_request_search.set_image(image)
-            button_request_search.set_relief(gtk.RELIEF_NONE)
-            button_request_search.connect('clicked', self.sig_request_open)
-            button_request_search.set_sensitive(False)
-            self.status_hbox.pack_start(button_request_search, False, True)
-        self.tooltips.set_tip(self.button_request_search, _('Read my Requests'))
-
-        if not update:
             self.secure_img = gtk.Image()
             self.secure_img.set_from_stock('tryton-lock', gtk.ICON_SIZE_MENU)
-            self.status_hbox.pack_start(self.secure_img, False, True)
+            self.status_hbox.pack_start(self.secure_img, False, True, padding=2)
 
-        if not update:
             self.status_hbox.show_all()
 
     def _set_menu_file(self):
@@ -402,7 +382,7 @@ class Main(object):
 
         imagemenuitem_open_request = gtk.ImageMenuItem(_('_Read my Requests'))
         image = gtk.Image()
-        image.set_from_stock('tryton-find', gtk.ICON_SIZE_MENU)
+        image.set_from_stock('tryton-mail-message', gtk.ICON_SIZE_MENU)
         imagemenuitem_open_request.set_image(image)
         imagemenuitem_open_request.connect('activate', self.sig_request_open)
         imagemenuitem_open_request.set_accel_path('<tryton>/User/Read my Requests')
@@ -579,6 +559,51 @@ class Main(object):
     def _set_menu_options(self):
         menu_options = gtk.Menu()
 
+        menuitem_toolbar = gtk.MenuItem(_('_Toolbar'))
+        menu_options.add(menuitem_toolbar)
+
+        menu_toolbar = gtk.Menu()
+        menu_toolbar.set_accel_group(self.accel_group)
+        menu_toolbar.set_accel_path('<tryton>/Options/Toolbar')
+        menuitem_toolbar.set_submenu(menu_toolbar)
+
+        radiomenuitem_default = gtk.RadioMenuItem(label=_('_Default'))
+        radiomenuitem_default.connect('activate',
+                lambda x: self.sig_toolbar('default'))
+        radiomenuitem_default.set_accel_path('<tryton>/Options/Toolbar/Default')
+        menu_toolbar.add(radiomenuitem_default)
+        if (CONFIG['client.toolbar'] or 'both') == 'default':
+            radiomenuitem_default.set_active(True)
+
+        radiomenuitem_both = gtk.RadioMenuItem(group=radiomenuitem_default,
+                label=_('_Text and Icons'))
+        radiomenuitem_both.connect('activate',
+                lambda x: self.sig_toolbar('both'))
+        radiomenuitem_both.set_accel_path(
+                '<tryton>/Options/Toolbar/Text and Icons')
+        menu_toolbar.add(radiomenuitem_both)
+        if (CONFIG['client.toolbar'] or 'both') == 'both':
+            radiomenuitem_both.set_active(True)
+
+        radiomenuitem_icons = gtk.RadioMenuItem(group=radiomenuitem_default,
+                label=_('_Icons'))
+        radiomenuitem_icons.connect('activate',
+                lambda x: self.sig_toolbar('icons'))
+        radiomenuitem_icons.set_accel_path('<tryton>/Options/Toolbar/Icons')
+        menu_toolbar.add(radiomenuitem_icons)
+        if (CONFIG['client.toolbar'] or 'both') == 'icons':
+            radiomenuitem_icons.set_active(True)
+
+        radiomenuitem_text = gtk.RadioMenuItem(group=radiomenuitem_default,
+                label=_('_Text'))
+        radiomenuitem_text.connect('activate',
+                lambda x: self.sig_toolbar('text'))
+        radiomenuitem_text.set_accel_path('<tryton>/Options/Toolbar/Text')
+        menu_toolbar.add(radiomenuitem_text)
+        if (CONFIG['client.toolbar'] or 'both') == 'text':
+            radiomenuitem_text.set_active(True)
+
+        # Menubar accelerators
         menuitem_menubar = gtk.MenuItem(_('_Menubar'))
         menu_options.add(menuitem_menubar)
 
@@ -587,41 +612,13 @@ class Main(object):
         menu_menubar.set_accel_path('<tryton>/Options/Menubar')
         menuitem_menubar.set_submenu(menu_menubar)
 
-        radiomenuitem_default = gtk.RadioMenuItem(label=_('_Default'))
-        radiomenuitem_default.connect('activate',
-                lambda x: self.sig_menubar('default'))
-        radiomenuitem_default.set_accel_path('<tryton>/Options/Menubar/Default')
-        menu_menubar.add(radiomenuitem_default)
-        if (CONFIG['client.toolbar'] or 'both') == 'default':
-            radiomenuitem_default.set_active(True)
-
-        radiomenuitem_both = gtk.RadioMenuItem(group=radiomenuitem_default,
-                label=_('_Text and Icons'))
-        radiomenuitem_both.connect('activate',
-                lambda x: self.sig_menubar('both'))
-        radiomenuitem_both.set_accel_path(
-                '<tryton>/Options/Menubar/Text and Icons')
-        menu_menubar.add(radiomenuitem_both)
-        if (CONFIG['client.toolbar'] or 'both') == 'both':
-            radiomenuitem_both.set_active(True)
-
-        radiomenuitem_icons = gtk.RadioMenuItem(group=radiomenuitem_default,
-                label=_('_Icons'))
-        radiomenuitem_icons.connect('activate',
-                lambda x: self.sig_menubar('icons'))
-        radiomenuitem_icons.set_accel_path('<tryton>/Options/Menubar/Icons')
-        menu_menubar.add(radiomenuitem_icons)
-        if (CONFIG['client.toolbar'] or 'both') == 'icons':
-            radiomenuitem_icons.set_active(True)
-
-        radiomenuitem_text = gtk.RadioMenuItem(group=radiomenuitem_default,
-                label=_('_Text'))
-        radiomenuitem_text.connect('activate',
-                lambda x: self.sig_menubar('text'))
-        radiomenuitem_text.set_accel_path('<tryton>/Options/Menubar/Text')
-        menu_menubar.add(radiomenuitem_text)
-        if (CONFIG['client.toolbar'] or 'both') == 'text':
-            radiomenuitem_text.set_active(True)
+        checkmenuitem_accel = gtk.CheckMenuItem(_('Change Accelerators'))
+        checkmenuitem_accel.connect('activate',
+                lambda menuitem: self.sig_accel_change(menuitem.get_active()))
+        checkmenuitem_accel.set_accel_path('<tryton>/Options/Menubar/Accel')
+        menu_menubar.add(checkmenuitem_accel)
+        if CONFIG['client.can_change_accelerators']:
+            checkmenuitem_accel.set_active(True)
 
         menuitem_mode = gtk.MenuItem(_('_Mode'))
         menu_options.add(menuitem_mode)
@@ -662,15 +659,23 @@ class Main(object):
         if CONFIG['form.toolbar']:
             checkmenuitem_toolbar.set_active(True)
 
-        checkmenuitem_tree_width = gtk.CheckMenuItem(_('Save Columns Width'))
-        checkmenuitem_tree_width.connect('activate',
-                lambda menuitem: CONFIG.__setitem__('client.tree_width',
+        checkmenuitem_statusbar = gtk.CheckMenuItem(_('Statusbar'))
+        checkmenuitem_statusbar.connect('activate',
+                lambda menuitem: self.sig_statusbar_change(menuitem.get_active()))
+        checkmenuitem_statusbar.set_accel_path('<tryton>/Options/Form/Statusbar')
+        menu_form.add(checkmenuitem_statusbar)
+        if CONFIG['form.statusbar']:
+            checkmenuitem_statusbar.set_active(True)
+
+        checkmenuitem_save_width_height = gtk.CheckMenuItem(_('Save Width/Height'))
+        checkmenuitem_save_width_height.connect('activate',
+                lambda menuitem: CONFIG.__setitem__('client.save_width_height',
                     menuitem.get_active()))
-        checkmenuitem_tree_width.set_accel_path(
-                '<tryton>/Options/Form/Save Columns Width')
-        menu_form.add(checkmenuitem_tree_width)
-        if CONFIG['client.tree_width']:
-            checkmenuitem_tree_width.set_active(True)
+        checkmenuitem_save_width_height.set_accel_path(
+                '<tryton>/Options/Form/Save Width Height')
+        menu_form.add(checkmenuitem_save_width_height)
+        if CONFIG['client.save_width_height']:
+            checkmenuitem_save_width_height.set_active(True)
 
         checkmenuitem_spellcheck = gtk.CheckMenuItem(_('Spell Checking'))
         checkmenuitem_spellcheck.connect('activate',
@@ -725,35 +730,6 @@ class Main(object):
         if (CONFIG['client.form_tab'] or 'left') == 'bottom':
             radiomenuitem_bottom.set_active(True)
 
-        menuitem_orientation = gtk.MenuItem(_('Tabs Orientation'))
-        menu_form.add(menuitem_orientation)
-
-        menu_orientation = gtk.Menu()
-        menu_orientation.set_accel_group(self.accel_group)
-        menu_orientation.set_accel_path('<tryton>/Options/Tabs Orientation')
-        menuitem_orientation.set_submenu(menu_orientation)
-
-        radiomenuitem_horizontal = gtk.RadioMenuItem(label=_('Horizontal'))
-        radiomenuitem_horizontal.connect('activate',
-                lambda x: CONFIG.__setitem__('client.form_tab_orientation',
-                    0))
-        radiomenuitem_horizontal.set_accel_path(
-                '<tryton>/Options/Tabs Orientation/Horizontal')
-        menu_orientation.add(radiomenuitem_horizontal)
-        if (str(CONFIG['client.form_tab_orientation']) or '0') == '0':
-            radiomenuitem_horizontal.set_active(True)
-
-        radiomenuitem_vertical = gtk.RadioMenuItem(group=radiomenuitem_horizontal,
-                label=_('Vertical'))
-        radiomenuitem_vertical.connect('activate',
-                lambda x: CONFIG.__setitem__('client.form_tab_orientation',
-                    90))
-        radiomenuitem_vertical.set_accel_path(
-                '<tryton>/Options/Tabs Orientation/Vertical')
-        menu_orientation.add(radiomenuitem_vertical)
-        if (str(CONFIG['client.form_tab_orientation']) or '0') == '90':
-            radiomenuitem_vertical.set_active(True)
-
         menuitem_actions = gtk.MenuItem(_('File _Actions...'))
         self.menuitem_actions = menuitem_actions
         menuitem_actions.connect('activate', self.sig_file_actions)
@@ -895,6 +871,14 @@ class Main(object):
         toolbutton_attach.connect('clicked', self._sig_child_call, 'but_attach')
         self.buttons['but_attach'] = toolbutton_attach
 
+        self.toolbar.insert(gtk.SeparatorToolItem(), -1)
+
+        toolbutton_request = gtk.ToolButton('tryton-mail-message')
+        self.toolbutton_request = toolbutton_request
+        self.toolbar.insert(toolbutton_request, -1)
+        toolbutton_request.connect('clicked', self.sig_request_open)
+        self.buttons['but_request'] = toolbutton_request
+
     def set_toolbar_label(self):
         labels = {
             'but_new': _('_New'),
@@ -909,6 +893,7 @@ class Main(object):
             'but_action': _('Action'),
             'but_print': _('Print'),
             'but_attach': _('Attachment(0)'),
+            'but_request': _('Request'),
         }
         tooltips = {
             'but_new': _('Create a new record'),
@@ -923,6 +908,7 @@ class Main(object):
             'but_action': _('Action'),
             'but_print': _('Print'),
             'but_attach': _('Add an attachment to the record'),
+            'but_request': _('Request'),
         }
         for i in self.buttons:
             self.buttons[i].set_label(labels[i])
@@ -961,30 +947,45 @@ class Main(object):
         self.menuitem_shortcut.set_submenu(menu)
         self.menuitem_shortcut.set_sensitive(False)
 
+    def sig_accel_change(self, value):
+        CONFIG['client.can_change_accelerators'] = value
+        return self.sig_accel()
+
+    def sig_accel(self):
+        menubar = CONFIG['client.can_change_accelerators']
+        settings = gtk.settings_get_default()
+        if menubar:
+            settings.set_property('gtk-can-change-accels', True)
+        else:
+            settings.set_property('gtk-can-change-accels', False)
+
     def sig_toolbar_change(self, value):
         CONFIG['form.toolbar'] = value
-        return self.sig_toolbar()
+        return self.sig_toolbar_show()
 
-    def sig_toolbar(self):
+    def sig_toolbar_show(self):
         toolbar = CONFIG['form.toolbar']
         if toolbar:
             self.toolbar.show()
         else:
             self.toolbar.hide()
 
+    def sig_statusbar_change(self, value):
+        CONFIG['form.statusbar'] = value
+        return self.sig_statusbar_show()
+
+    def sig_statusbar_show(self):
+        statusbar = CONFIG['form.statusbar']
+        if statusbar:
+            self.status_hbox.show()
+        else:
+            self.status_hbox.hide()
+
     def sig_mode_change(self, pda_mode=False):
         CONFIG['client.modepda'] = pda_mode
-        return self.sig_mode()
+        return
 
-    def sig_mode(self):
-        pda_mode = CONFIG['client.modepda']
-        if pda_mode:
-            self.status_hbox.hide()
-        else:
-            self.status_hbox.show()
-        return pda_mode
-
-    def sig_menubar(self, option):
+    def sig_toolbar(self, option):
         CONFIG['client.toolbar'] = option
         if option == 'default':
             self.toolbar.set_style(False)
@@ -999,10 +1000,6 @@ class Main(object):
     def sig_form_tab(option):
         CONFIG['client.form_tab'] = option
 
-    @staticmethod
-    def sig_form_tab_orientation(option):
-        CONFIG['client.form_tab_orientation'] = option
-
     def sig_file_actions(self, widget):
         FileActions(self.window).run()
 
@@ -1028,8 +1025,7 @@ class Main(object):
             if prefs and 'language_direction' in prefs:
                 translate.set_language_direction(prefs['language_direction'])
                 CONFIG['client.language_direction'] = prefs['language_direction']
-            sb_id = self.sb_username.get_context_id('message')
-            self.sb_username.push(sb_id, prefs.get('status_bar', ''))
+            self.sb_username.set_text(prefs.get('status_bar', ''))
             if prefs and 'language' in prefs:
                 translate.setlang(prefs['language'], prefs.get('locale'))
                 if CONFIG['client.lang'] != prefs['language']:
@@ -1073,6 +1069,8 @@ class Main(object):
 
     def request_set(self, exception=False):
         try:
+            if not rpc._USER:
+                return
             if not exception:
                 res = rpc.execute('model', 'res.request', 'request_get')
                 if not res:
@@ -1080,20 +1078,17 @@ class Main(object):
                 ids, ids2 = res
             else:
                 ids, ids2 = rpc.execute('model', 'res.request', 'request_get')
-            if len(ids):
-                if len(ids) == 1:
-                    message = _('%s request') % len(ids)
-                else:
-                    message = _('%s requests') % len(ids)
+            label = _('Requests (%s/%s)') % (len(ids), len(ids2))
+            self.buttons['but_request'].set_label(label)
+            self.tooltips.set_tip(self.buttons['but_request'], label)
+            if not ids:
+                self.buttons['but_request'].set_stock_id('tryton-mail-message')
             else:
-                message = _('No request')
-            if len(ids2):
-                if len(ids2) == 1:
-                    message += _(' - %s request sent') % len(ids2)
-                else:
-                    message += _(' - %s requests sent') % len(ids2)
-            sb_id = self.sb_requests.get_context_id('message')
-            self.sb_requests.push(sb_id, message)
+                self.buttons['but_request'].set_stock_id(
+                        'tryton-mail-message-new')
+            message = _('Waiting requests: %s received - %s sent') % (len(ids),
+                        len(ids2))
+            self.sb_requests.set_text(message)
             return (ids, ids2)
         except:
             if exception:
@@ -1151,11 +1146,10 @@ class Main(object):
         if not self.menuitem_shortcut.get_property('sensitive'):
             self.shortcut_set()
         self.toolbutton_menu.set_sensitive(True)
+        self.toolbutton_request.set_sensitive(True)
         self.menuitem_user.set_sensitive(True)
         self.menuitem_form.set_sensitive(True)
         self.menuitem_plugins.set_sensitive(True)
-        self.button_request_new.set_sensitive(True)
-        self.button_request_search.set_sensitive(True)
         self.notebook.grab_focus()
         return True
 
@@ -1171,19 +1165,16 @@ class Main(object):
                 res = self._win_del()
             else:
                 res = False
-        sb_id = self.sb_requests.get_context_id('message')
-        self.sb_requests.push(sb_id, '')
-        sb_id = self.sb_username.get_context_id('message')
-        self.sb_username.push(sb_id, _('Not logged!'))
-        sb_id = self.sb_servername.get_context_id('message')
-        self.sb_servername.push(sb_id, _('Press Ctrl+O to login'))
+        self.sb_username.set_text('')
+        self.sb_servername.set_text('')
+        self.sb_requests.set_text('')
         self.shortcut_unset()
         self.toolbutton_menu.set_sensitive(False)
+        self.toolbutton_request.set_sensitive(False)
+        self.toolbutton_request.set_label(_('Request'))
         self.menuitem_user.set_sensitive(False)
         self.menuitem_form.set_sensitive(False)
         self.menuitem_plugins.set_sensitive(False)
-        self.button_request_new.set_sensitive(False)
-        self.button_request_search.set_sensitive(False)
         if disconnect:
             rpc.logout()
         self.refresh_ssl()
@@ -1198,8 +1189,8 @@ class Main(object):
                     '\n' + info)
             self.secure_img.show()
         else:
-            self.tooltips.set_tip(self.secure_img, '')
             self.secure_img.hide()
+            self.tooltips.set_tip(self.secure_img, '')
 
     def sig_tips(self, *args):
         Tips(self.window)
@@ -1241,10 +1232,8 @@ class Main(object):
                 prefs = common.process_exception(exception, self.window, *args)
                 if not prefs:
                     return False
-        sb_id = self.sb_username.get_context_id('message')
-        self.sb_username.push(sb_id, prefs['status_bar'] or '')
-        sb_id = self.sb_servername.get_context_id('message')
-        self.sb_servername.push(sb_id, '%s@%s:%d/%s' % (rpc._USERNAME,
+        self.sb_username.set_text(prefs.get('status_bar', ''))
+        self.sb_servername.set_text('%s@%s:%d/%s' % (rpc._USERNAME,
             rpc._SOCK.hostname, rpc._SOCK.port, rpc._DATABASE))
         if not prefs[menu_type]:
             if quiet:
@@ -1277,6 +1266,8 @@ class Main(object):
 
     @staticmethod
     def sig_quit(widget=None):
+        CONFIG['client.default_width'] = Main.get_main()._width
+        CONFIG['client.default_height'] = Main.get_main()._height
         CONFIG.save()
         if hasattr(gtk, 'accel_map_save'):
             gtk.accel_map_save(os.path.join(get_home_dir(), '.trytonsc'))
@@ -1296,6 +1287,13 @@ class Main(object):
             return False
         return True
 
+    def sig_configure(self, widget, event):
+        if hasattr(event, 'width') \
+                and hasattr(event, 'height'):
+            self._width =  int(event.width)
+            self._height = int(event.height)
+        return False
+
     def win_add(self, page):
         previous_page_id = self.notebook.get_current_page()
         previous_widget = self.notebook.get_nth_page(previous_page_id)
@@ -1349,7 +1347,7 @@ class Main(object):
         if not view:
             view = self._wid_get()
         for i in self.buttons:
-            if i == 'but_menu':
+            if i in ('but_menu', 'but_request'):
                 continue
             if self.buttons[i]:
                 self.buttons[i].set_sensitive(
@@ -1434,11 +1432,6 @@ class Main(object):
     def _sig_page_changt(self, notebook, page, page_num):
         self.last_page = self.current_page
         self.current_page = self.notebook.get_current_page()
-        title = 'Tryton'
-        page = self._wid_get()
-        if page:
-            title += ' - ' + page.name
-        self.window.set_title(title)
         self.sb_set()
 
     def sig_db_new(self, widget):
@@ -1465,8 +1458,10 @@ class Main(object):
                 "database.\nAre you really sure to proceed?"), self.window)
         if sure == "ko" or sure == "cancel":
             return
+        rpcprogress = common.RPCProgress('db_exec', (host, int(port), 'drop',
+            dbname, passwd), self.window)
         try:
-            rpc.db_exec(host, int(port), 'drop', dbname, passwd)
+            rpcprogress.run()
         except Exception, exception:
             self.refresh_ssl()
             if exception[0] == "AccessDenied":
@@ -1491,15 +1486,16 @@ class Main(object):
         if not filename:
             return
         dialog = DBRestore(self.window, filename=filename)
-        url, dbname, passwd = dialog.run(self.window)
+        url, dbname, passwd, update = dialog.run(self.window)
         if dbname:
             file_p = file(filename, 'rb')
             data_b64 = base64.encodestring(file_p.read())
             file_p.close()
             host, port = url.rsplit(':' , 1)
+            rpcprogress = common.RPCProgress('db_exec', (host, int(port),
+                'restore', dbname, passwd, data_b64, update), self.window)
             try:
-                res = rpc.db_exec(host, int(port), 'restore', dbname, passwd, \
-                        data_b64)
+                res = rpcprogress.run()
             except Exception, exception:
                 self.refresh_ssl()
                 if exception[0] == \
@@ -1539,8 +1535,10 @@ class Main(object):
             return
 
         host, port = url.rsplit(':', 1)
+        rpcprogress = common.RPCProgress('db_exec', (host, int(port), 'dump',
+            dbname, passwd), self.window)
         try:
-            dump_b64 = rpc.db_exec(host, int(port), 'dump', dbname, passwd)
+            dump_b64 = rpcprogress.run()
         except Exception, exception:
             if exception[0] == "Couldn't dump database with password":
                 common.warning(_("It is not possible to dump a password " \
@@ -1565,7 +1563,8 @@ class Main(object):
 
         filename = common.file_selection(_('Save As...'), \
                 action=gtk.FILE_CHOOSER_ACTION_SAVE, parent=self.window, \
-                preview=False)
+                preview=False,
+                filename=dbname + '-' + time.strftime('%Y%m%d%H%M') + '.dump')
 
         if filename:
             file_ = file(filename, 'wb')
