@@ -1,7 +1,8 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of this repository contains the full copyright notices and license terms.
+#This file is part of Tryton.  The COPYRIGHT file at the top level of
+#this repository contains the full copyright notices and license terms.
 from tryton.rpc import RPCProxy
 import tryton.rpc as rpc
-from tryton.common import DT_FORMAT, DHM_FORMAT, HM_FORMAT
+from tryton.common import DT_FORMAT, DHM_FORMAT, HM_FORMAT, safe_eval
 import time
 import datetime
 from decimal import Decimal
@@ -41,8 +42,21 @@ class CharField(object):
         model.on_change_with(self.name)
 
     def domain_get(self, model):
-        dom = self.attrs.get('domain', '[]')
-        return model.expr_eval(dom)
+        dom = self.attrs.get('domain', [])
+        def eval_domain(domain):
+            res = []
+            for arg in domain:
+                if isinstance(arg, basestring):
+                    if arg in ('AND', 'OR'):
+                        res.append(arg)
+                    else:
+                        res.append(model.expr_eval(arg))
+                elif isinstance(arg, tuple):
+                    res.append(arg)
+                elif isinstance(arg, list):
+                    res.append(eval_domain(arg))
+            return res
+        return eval_domain(dom)
 
     def context_get(self, model, check_load=True, eval_context=True):
         context = {}
@@ -113,7 +127,7 @@ class CharField(object):
         state_changes = self.attrs.get('states', {})
         if isinstance(state_changes, basestring):
             try:
-                state_changes = eval(state_changes)
+                state_changes = safe_eval(state_changes)
             except:
                 return
         for key in states:
@@ -225,7 +239,7 @@ class FloatField(CharField):
                 model.signal('record-changed', model)
 
 
-class NumericField(FloatField):
+class NumericField(CharField):
 
     def set_client(self, model, value, force_change=False):
         value = Decimal(str(value))
@@ -414,7 +428,7 @@ class M2MField(CharField):
                     rpc.CONTEXT)
         except:
             return self.get_client(model)
-        return ', '.join([x['rec_name'] for x in result])
+        return ', '.join(x['rec_name'] for x in result)
 
 
 class O2MField(CharField):
@@ -430,7 +444,8 @@ class O2MField(CharField):
         from group import ModelRecordGroup
         mod = ModelRecordGroup(self.attrs['relation'], {}, model.window,
                 parent=model, parent_name=self.attrs.get('relation_field', ''),
-                context=self.context)
+                context=self.context,
+                parent_datetime_field=self.attrs.get('datetime_field'))
         mod.signal_connect(mod, 'model-changed', self._model_changed)
         return mod
 
@@ -488,7 +503,8 @@ class O2MField(CharField):
         from group import ModelRecordGroup
         mod = ModelRecordGroup(self.attrs['relation'], {}, model.window,
                 parent=model, parent_name=self.attrs.get('relation_field', ''),
-                context=self.context)
+                context=self.context,
+                parent_datetime_field=self.attrs.get('datetime_field'))
         mod.signal_connect(mod, 'model-changed', self._model_changed)
         model.value[self.name] = mod
         #self.internal.signal_connect(self.internal, 'model-changed',
@@ -520,7 +536,8 @@ class O2MField(CharField):
         model.value[self.name] = ModelRecordGroup(
                 self.attrs['relation'], fields, model.window, parent=model,
                 parent_name=self.attrs.get('relation_field', ''),
-                context=self.context)
+                context=self.context,
+                parent_datetime_field=self.attrs.get('datetime_field'))
         model.value[self.name].signal_connect(model.value[self.name],
                 'model-changed', self._model_changed)
         mod = None
