@@ -1,4 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of this repository contains the full copyright notices and license terms.
+#This file is part of Tryton.  The COPYRIGHT file at the top level of
+#this repository contains the full copyright notices and license terms.
 from tryton.rpc import RPCProxy
 import tryton.rpc as rpc
 from record import ModelRecord
@@ -72,11 +73,13 @@ class ModelList(list):
 class ModelRecordGroup(SignalEvent):
 
     def __init__(self, resource, fields, window, ids=None, parent=None,
-            parent_name='', context=None, readonly=False):
+            parent_name='', context=None, readonly=False,
+            parent_datetime_field=None):
         super(ModelRecordGroup, self).__init__()
         self.window = window
         self.parent = parent
         self.parent_name = parent_name
+        self.parent_datetime_field = parent_datetime_field
         self._context = context or {}
         self.resource = resource
         self.rpc = RPCProxy(resource)
@@ -94,7 +97,7 @@ class ModelRecordGroup(SignalEvent):
             self.readonly = True
 
     def __repr__(self):
-        return '<ModelRecordGroup %s>' % (self.resource,)
+        return '<ModelRecordGroup %s at %s>' % (self.resource, id(self))
 
     @staticmethod
     def mfields_load(fkeys, models):
@@ -222,6 +225,9 @@ class ModelRecordGroup(SignalEvent):
     def _get_context(self):
         ctx = rpc.CONTEXT.copy()
         ctx.update(self._context)
+        if self.parent_datetime_field:
+            ctx['_datetime'] = self.parent.get_eval(check_load=False)\
+                    [self.parent_datetime_field]
         return ctx
     context = property(_get_context)
 
