@@ -1,4 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of this repository contains the full copyright notices and license terms.
+#This file is part of Tryton.  The COPYRIGHT file at the top level of
+#this repository contains the full copyright notices and license terms.
 import re
 import time
 from tryton.rpc import RPCProxy
@@ -136,8 +137,7 @@ class ModelRecord(SignalEvent):
             if (get_readonly or \
                     not mfield.get_state_attrs(self).get('readonly', False)) \
                 and (not get_modifiedonly \
-                    or (mfield.name in self.modified_fields \
-                        or isinstance(mfield, field.O2MField))):
+                   or mfield.name in self.modified_fields):
                 value.append((name, mfield.get(self, check_load=check_load,
                     readonly=get_readonly, modified=get_modifiedonly)))
         value = dict(value)
@@ -179,7 +179,7 @@ class ModelRecord(SignalEvent):
         else:
             if not self.is_modified():
                 return self.id
-            value = self.get(get_readonly=False, get_modifiedonly=True)
+            value = self.get(get_readonly=True, get_modifiedonly=True)
             context = self.context_get()
             context = context.copy()
             context['_timestamp'] = self.get_timestamp()
@@ -346,13 +346,13 @@ class ModelRecord(SignalEvent):
         if self.parent and self.parent_name:
             ctx['_parent_' + self.parent_name] = EvalEnvironment(self.parent,
                     check_load)
-        val = eval(dom, ctx)
+        val = common.safe_eval(dom, ctx)
         return val
 
     def on_change(self, fieldname, attr):
         args = {}
         if isinstance(attr, basestring):
-            attr = eval(attr)
+            attr = common.safe_eval(attr)
         for arg in attr:
             try:
                 args[arg] = self.expr_eval(arg)
