@@ -1,4 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of this repository contains the full copyright notices and license terms.
+#This file is part of Tryton.  The COPYRIGHT file at the top level of
+#this repository contains the full copyright notices and license terms.
 "Screen"
 import xml.dom.minidom
 from tryton.rpc import RPCProxy
@@ -10,6 +11,7 @@ from tryton.signal_event import SignalEvent
 from tryton.common import node_attributes
 import gobject
 import tryton.common as common
+import copy
 
 
 class Screen(SignalEvent):
@@ -75,7 +77,7 @@ class Screen(SignalEvent):
         self.form = form
         self.fields_view_tree = None
         self.exclude_field = exclude_field
-        self.sort = sort or []
+        self.sort = sort
         self.view_to_load = []
 
         if view_type:
@@ -256,6 +258,7 @@ class Screen(SignalEvent):
             if self.current_view.view_type == 'form':
                 self.new()
         self.current_view.set_cursor()
+        self.current_view.cancel()
         self.display()
         # TODO: set True or False accoring to the type
 
@@ -312,6 +315,33 @@ class Screen(SignalEvent):
                 _parse_fields(node2, fields)
         xml_dom = xml.dom.minidom.parseString(arch)
         _parse_fields(xml_dom, fields)
+
+        for dom in common.filter_domain(self.domain):
+            if '.' in dom[0]:
+                field1, field2 = dom[0].split('.', 1)
+            else:
+                field1, field2 = dom[0], 'id'
+            if field1 in fields:
+                field_dom = fields[field1].setdefault('domain', [])
+                if dom[1] in ('child_of', 'not child_of') \
+                        and field2 == 'id':
+                    dom = copy.copy(dom)
+                    if len(dom) == 4:
+                        field2 = dom[3]
+                        dom = (dom[0], dom[1], dom[2])
+                    else:
+                        field2 = field1
+                if isinstance(field_dom, basestring):
+                    fields[field1]['domain'] = '[' \
+                            + str(tuple([field2] + list(dom[1:]))) \
+                            + ',' + field_dom + ']'
+                else:
+                    fields[field1]['domain'] = [
+                            tuple([field2] + list(dom[1:])),
+                            field_dom]
+                if dom[1] == '!=' and dom[2] == False:
+                    fields[field1]['required'] = True
+
         for node in xml_dom.childNodes:
             if node.localName == 'tree':
                 self.fields_view_tree = {'arch': arch, 'fields': fields}
