@@ -1,4 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of this repository contains the full copyright notices and license terms.
+#This file is part of Tryton.  The COPYRIGHT file at the top level of
+#this repository contains the full copyright notices and license terms.
 import gtk
 import gettext
 from tryton.common import message, TRYTON_ICON
@@ -201,7 +202,9 @@ class ViewForm(ParserView):
         del self.buttons
 
     def cancel(self):
-        pass
+        for widgets in self.widgets.values():
+            for widget in widgets:
+                widget.widget.cancel()
 
     def set_value(self):
         model = self.screen.current_model
