@@ -1,4 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of this repository contains the full copyright notices and license terms.
+#This file is part of Tryton.  The COPYRIGHT file at the top level of
+#this repository contains the full copyright notices and license terms.
 import gobject
 import gtk
 import gettext
@@ -281,11 +282,14 @@ class Many2One(WidgetInterface):
                 self.wid_text.grab_focus()
 
                 try:
+                    if self.wid_text.get_text():
+                        dom = [('rec_name', 'ilike',
+                            '%' + self.wid_text.get_text() + '%'),
+                            domain]
+                    else:
+                        dom = domain
                     ids = rpc.execute('model', self.attrs['relation'],
-                            'search',
-                            [('rec_name', 'ilike', self.wid_text.get_text()),
-                                domain],
-                            0, _LIMIT, None, context)
+                            'search', dom, 0, _LIMIT, None, context)
                 except Exception, exception:
                     self.focus_out = True
                     common.process_exception(exception, self._window)
@@ -355,11 +359,14 @@ class Many2One(WidgetInterface):
                 self.wid_text.grab_focus()
 
                 try:
+                    if self.wid_text.get_text():
+                        dom = [('rec_name', 'ilike',
+                            '%' + self.wid_text.get_text() + '%'),
+                            domain]
+                    else:
+                        dom = domain
                     ids = rpc.execute('model', self.attrs['relation'],
-                            'search',
-                            [('rec_name', 'ilike', self.wid_text.get_text()),
-                                domain],
-                            0, _LIMIT, None, context)
+                            'search', dom, 0, _LIMIT, None, context)
                 except Exception, exception:
                     self.focus_out = True
                     common.process_exception(exception, self._window)
@@ -470,8 +477,8 @@ class Many2One(WidgetInterface):
             return False
         screen = Screen(self.attrs['relation'], self._window)
         screen.load([obj_id])
-        act['domain'] = screen.current_model.expr_eval(act.get('domain', []),
-                check_load=False)
+        act['domain'] = str(screen.current_model.expr_eval(act.get('domain', []),
+                check_load=False))
         act['context'] = str(screen.current_model.expr_eval(
             act.get('context', {}), check_load=False))
         data['model'] = self.model_type
