@@ -29,10 +29,14 @@ def _create_menu(self, attrs):
     menuitem_set_to_default.connect('activate',
             lambda *x: self._menu_sig_default_get())
     menu_title.add(menuitem_set_to_default)
-    menuitem_set_default = gtk.MenuItem(_('Set Default'), True)
+    menuitem_set_default = gtk.MenuItem(_('Set as default'), True)
     menuitem_set_default.connect('activate',
             lambda *x: self._menu_sig_default_set())
     menu_title.add(menuitem_set_default)
+    menuitem_reset_default = gtk.MenuItem(_('Reset default'), True)
+    menuitem_reset_default.connect('activate',
+            lambda *x: self._menu_sig_default_set(reset=True))
+    menu_title.add(menuitem_reset_default)
     menuitem_title.set_submenu(menu_title)
 
     menubar.add(menuitem_title)
@@ -374,10 +378,13 @@ class Dialog(object):
         context = rpc.CONTEXT.copy()
 
         try:
+            if self.wid_text.get_text():
+                dom = [('rec_name', 'ilike',
+                        '%' + self.wid_text.get_text() + '%'), domain]
+            else:
+                dom = domain
             ids = rpc.execute('model', self.attrs['relation'],
-                    'search',
-                    [('rec_name', 'ilike', self.wid_text.get_text()), domaini],
-                    0, _LIMIT, None, context)
+                    'search', dom, 0, _LIMIT, None, context)
         except Exception, exception:
             common.process_exception(exception, self._window)
             return False
@@ -406,7 +413,7 @@ class Dialog(object):
     def _menu_sig_default_get(self):
         pass
 
-    def _menu_sig_default_set(self):
+    def _menu_sig_default_set(self, reset=False):
         pass
 
     def new(self):
@@ -572,7 +579,8 @@ class One2Many(WidgetInterface):
                 domain = modelfield.domain_get(self._view.model)
             dia = Dialog(self.attrs['relation'], parent=self._view.model,
                     model=self.screen.current_model, attrs=self.attrs,
-                    window=self._window, readonly=readonly, domain=domain)
+                    window=self._window, readonly=readonly, domain=domain,
+                    model_ctx=self.screen.models.context)
             res, value = dia.run()
             dia.destroy()
 
@@ -600,11 +608,13 @@ class One2Many(WidgetInterface):
         removed_ids = self._view.modelfield.get_removed_ids(self._view.model)
 
         try:
+            if self.wid_text.get_text():
+                dom = [('rec_name', 'ilike', '%' + self.wid_text.get_text() + '%'),
+                    ['OR', domain, ('id', 'in', removed_ids)]]
+            else:
+                dom = ['OR', domain, ('id', 'in', removed_ids)]
             ids = rpc.execute('model', self.attrs['relation'],
-                    'search',
-                    [('rec_name', 'ilike', self.wid_text.get_text()),
-                    ['OR', domain, ('id', 'in', removed_ids)]],
-                    0, _LIMIT, None, context)
+                    'search', dom, 0, _LIMIT, None, context)
         except Exception, exception:
             common.process_exception(exception, self._window)
             return False
