@@ -1,4 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of this repository contains the full copyright notices and license terms.
+#This file is part of Tryton.  The COPYRIGHT file at the top level of
+#this repository contains the full copyright notices and license terms.
 import gtk
 import gobject
 import gettext
@@ -167,11 +168,14 @@ class Reference(WidgetInterface):
                 context = self._view.modelfield.context_get(self._view.model)
 
                 try:
+                    if self.wid_text.get_text():
+                        dom = [('rec_name', 'ilike',
+                                '%' + self.wid_text.get_text() + '%'),
+                                domain]
+                    else:
+                        dom = domain
                     ids = rpc.execute('model', model,
-                            'search',
-                            [('rec_name', 'ilike', self.wid_text.get_text()),
-                                domain],
-                            0, _LIMIT, None, context)
+                            'search', dom, 0, _LIMIT, None, context)
                 except Exception, exception:
                     self.focus_out = True
                     self.changed = True
