@@ -366,7 +366,7 @@ class ViewList(ParserView):
         if not selection.data:
             return
         model = treeview.get_model()
-        data = eval(selection.data)
+        data = common.safe_eval(selection.data)
         drop_info = treeview.get_dest_row_at_pos(x, y)
         if drop_info:
             path, position = drop_info
@@ -446,10 +446,13 @@ class ViewList(ParserView):
         screen = Screen(self.screen.fields[path[1].name]['relation'],
                 self.window)
         screen.load([value])
-        act['domain'] = screen.current_model.expr_eval(act['domain'],
-                check_load=False)
-        act['context'] = str(screen.current_model.expr_eval(act['context'],
+        act['domain'] = str(screen.current_model.expr_eval(act.get('domain', []),
+                check_load=False))
+        act['context'] = str(screen.current_model.expr_eval(act.get('context', {}),
             check_load=False))
+        data['model'] = self.screen.name
+        data['id'] = value
+        data['ids'] = [value]
         return Action._exec_action(act, self.window, data, context)
 
     def click_and_action(self, atype, value, path):
@@ -477,7 +480,7 @@ class ViewList(ParserView):
         return None
 
     def destroy(self):
-        if CONFIG['client.tree_width']:
+        if CONFIG['client.save_width_height']:
             fields = {}
             last_col = None
             for col in self.widget_tree.get_columns():
