@@ -1,7 +1,7 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of this repository contains the full copyright notices and license terms.
+#This file is part of Tryton.  The COPYRIGHT file at the top level of
+#this repository contains the full copyright notices and license terms.
 import locale
 import gtk
-import math
 
 from tryton.rpc import RPCProxy
 from editabletree import EditableTreeView
@@ -30,6 +30,9 @@ from tryton.common.cellrendererfloat import CellRendererFloat
 from tryton.action import Action
 from tryton.translate import date_format
 import mx.DateTime
+import gettext
+
+_ = gettext.gettext
 
 def send_keys(renderer, editable, position, treeview):
     editable.connect('key_press_event', treeview.on_keypressed)
@@ -149,7 +152,7 @@ class ParserTree(ParserInterface):
                     'biginteger': 60,
                     'float': 80,
                     'numeric': 80,
-                    'float_time': 80,
+                    'float_time': 100,
                     'date': 90,
                     'datetime': 140,
                     'selection': 90,
@@ -186,10 +189,10 @@ class ParserTree(ParserInterface):
                         label.set_markup(label_str)
                     label_sum = gtk.Label()
                     label_sum.set_use_markup(True)
-                    if isinstance(fields.get('digits'), str):
+                    if isinstance(fields[fname].get('digits'), str):
                         digits = 2
                     else:
-                        digits = fields.get('digits', (16, 2))[1]
+                        digits = fields[fname].get('digits', (16, 2))[1]
                     dict_widget[i] = (fname, label, label_sum, digits,
                             label_bold)
             elif node.localName == 'button':
@@ -475,27 +478,20 @@ class Float(Char):
 
 class FloatTime(Char):
 
+    def __init__(self, field_name, model, treeview=None, attrs=None,
+            window=None):
+        super(FloatTime, self).__init__(field_name, model, treeview=treeview,
+                attrs=attrs, window=window)
+        self.conv = None
+        if attrs and attrs.get('float_time'):
+            self.conv = rpc.CONTEXT.get(attrs['float_time'])
+
     def get_textual_value(self, model):
         val = model[self.field_name].get_client(model)
-        value = '%02d:%02d' % (math.floor(abs(val)),
-                round(abs(val) % 1 + 0.01, 2) * 60)
-        if val < 0:
-            value = '-' + value
-        return value
+        return common.float_time_to_text(val, self.conv)
 
     def value_from_text(self, model, text):
-        try:
-            if text and ':' in text:
-                # assume <hours>:<minutes>
-                h, m = text.split(':')
-                h = h or 0
-                m = m or 0
-                return round(int(h) + int(m)/60.0, 2)
-            else:
-                # try float in locale notion
-                return locale.atof(text)
-        except:
-            return 0.0
+        return common.text_to_float_time(text, self.conv)
 
 class M2O(Char):
 
@@ -512,8 +508,12 @@ class M2O(Char):
         context = model[self.field_name].context_get(model)
 
         try:
-            ids = rpc_relation.search([('rec_name', 'ilike', text), domain],
-                    0, None, None, context)
+            if text:
+                dom = [('rec_name', 'ilike', '%' + text + '%'),
+                        domain]
+            else:
+                dom = domain
+            ids = rpc_relation.search(dom, 0, None, None, context)
         except Exception, exception:
             common.process_exception(exception, self.window)
             return '???'
@@ -536,8 +536,11 @@ class M2O(Char):
             rpc_relation = RPCProxy(relation)
 
             try:
-                ids = rpc_relation.search([('rec_name', 'ilike', text), domain],
-                        0, None, None, context)
+                if text:
+                    dom = [('rec_name', 'ilike', '%' + text + '%'), domain]
+                else:
+                    dom = domain
+                ids = rpc_relation.search(dom, 0, None, None, context)
             except Exception, exception:
                 common.process_exception(exception, self.window)
                 return False, False
@@ -630,8 +633,12 @@ class M2M(Char):
         domain = model[self.field_name].domain_get(model)
         context = model[self.field_name].context_get(model)
         try:
-            ids = rpc_relation.search([('rec_name', 'ilike', text), domain],
-                    0, _LIMIT, None, context)
+            if text:
+                dom = [('rec_name', 'ilike', '%' + text + '%'),
+                        domain]
+            else:
+                dom = domain
+            ids = rpc_relation.search(dom, 0, _LIMIT, None, context)
         except Exception, exception:
             common.process_exception(exception, self.window)
             return []
@@ -673,7 +680,8 @@ class Selection(Char):
         super(Selection, self).__init__(*args)
         self.renderer = CellRendererCombo()
         selection_data = gtk.ListStore(str, str)
-        selection = self.attrs.get('selection', [])
+        selection = self.attrs.get('selection', [])[:]
+        self.selection = selection[:]
         if 'relation' in self.attrs:
             try:
                 result = rpc.execute('model',
@@ -684,6 +692,7 @@ class Selection(Char):
             except Exception, exception:
                 common.process_exception(exception, self.window)
                 selection = []
+            self.selection = selection[:]
         else:
             if not isinstance(selection, (list, tuple)):
                 try:
@@ -692,11 +701,24 @@ class Selection(Char):
                 except Exception, exception:
                     common.process_exception(exception, self.window)
                     selection = []
+                self.selection = selection[:]
+
+            for dom in common.filter_domain(self.attrs.get('domain', [])):
+                if dom[1] in ('=', '!='):
+                    todel = []
+                    for i in range(len(selection)):
+                        if (dom[1] == '=' \
+                                and selection[i][0] != dom[2]) \
+                                or (dom[1] == '!=' \
+                                and selection[i][0] == dom[2]):
+                            todel.append(i)
+                    for i in todel[::-1]:
+                        del selection[i]
+
         if self.attrs.get('sort', True):
             selection.sort(lambda x, y: cmp(x[1], y[1]))
-        self.attrs['selection'] = selection
-        self.selection = selection
-        for i in self.selection:
+        self._selection = selection
+        for i in selection:
             selection_data.append(i)
         self.renderer.set_property('model', selection_data)
         self.renderer.set_property('text-column', 1)
@@ -709,7 +731,7 @@ class Selection(Char):
 
     def value_from_text(self, model, text):
         res = False
-        for val, txt in self.selection:
+        for val, txt in self._selection:
             if txt[:len(text)].lower() == text.lower():
                 if len(txt) == len(text):
                     return val
@@ -818,7 +840,7 @@ class Button(object):
 
         state_changes = self.attrs.get('states', {})
         if isinstance(state_changes, basestring):
-            state_changes = eval(state_changes)
+            state_changes = common.safe_eval(state_changes)
         if 'invisible' in state_changes:
             if model.expr_eval(state_changes['invisible'], check_load=False):
                 return True
